@@ -7,7 +7,7 @@ import subprocess
 import threading
 import time
 import ConfigParser
-from gi.repository import GLib, GObject, Gtk
+from gi.repository import GLib, GdkPixbuf, Gtk
 # Import special features if we're running Ubuntu Unity
 if (os.environ.get('DESKTOP_SESSION') == 'ubuntu' or
         os.environ.get('DESKTOP_SESSION') == 'ubuntu-2d'):
@@ -33,7 +33,7 @@ options = {
     # set the default RDP user to the local user by default
     'user': os.environ.get('USER', 'user'),
     'geometry': '1024x768',
-    'program': 'rdesktop',
+    'program': 'xfreerdp',
     'homeshare': 'false',
     'grabkeyboard': 'false',
     'fullscreen': 'false',
@@ -167,9 +167,11 @@ def run_program(window):
 
 # Open a terminal when freerdp needs user input
 def terminal_needed(host, cmdline):
+    terminal_args = ['xterm', '-hold', '-e']
     def prepend_terminal():
-        cmdline.insert(0, '-x')
-        cmdline.insert(0, 'x-terminal-emulator')
+        if cmdline[0] != 'xterm':
+            for x in reversed(terminal_args):
+                cmdline.insert(0, x)
     if cmdline[0] == 'xfreerdp':
         if '-sec-nla' not in cmdline:
             prepend_terminal()
@@ -281,21 +283,16 @@ e.g. "1024x768" or "80%"''')
         self.clioptionsentry.connect("activate",
                                      self.enter_connect, self.clioptionsentry)
 
-        # Combobox for program selection
-        program_store = Gtk.ListStore(str)
-        self.programs = {'rdesktop': 1, 'xfreerdp': 0}
-
-        # Adding our list of programs to the combobox.  We add these boolean
-        # values since the widget needs a boolean to define which selection is
-        # active
-        for key in self.programs:
-            program_store.append([key])
-        self.program_combo = Gtk.ComboBox.new_with_model(program_store)
-        self.program_combo.set_tooltip_text('List of supported RDP clients')
-        self.program_combo.connect("changed", self.on_program_combo_changed)
-        self.program_renderer_text = Gtk.CellRendererText()
-        self.program_combo.pack_start(self.program_renderer_text, True)
-        self.program_combo.add_attribute(self.program_renderer_text, "text", 0)
+        # Radio button for program selection
+        self.xfreerdpbutton = Gtk.RadioButton.new_with_label_from_widget(None, "FreeRDP")
+        self.xfreerdpbutton.connect("toggled", self.on_radio_button_toggled,
+                                    "xfreerdp")
+        self.rdesktopbutton = Gtk.RadioButton.new_from_widget(self.xfreerdpbutton)
+        self.rdesktopbutton.set_label("rdesktop")
+        self.rdesktopbutton.connect("toggled", self.on_radio_button_toggled,
+                                    "rdesktop")
+        self.xfreerdpbutton.set_tooltip_text('Choose a supported RDP client')
+        self.rdesktopbutton.set_tooltip_text('Choose a supported RDP client')
 
         # Checkbox for sharing our home directory
         self.homedirbutton = Gtk.CheckButton(label="Share Home Dir")
@@ -337,6 +334,8 @@ e.g. "1024x768" or "80%"''')
         grid.attach(geometrylabel, 0, 16, 4, 4)
         grid.attach(clioptionslabel, 0, 20, 4, 4)
         grid.attach(programlabel, 0, 24, 4, 4)
+        grid.attach(self.homedirbutton, 0, 28, 4, 4)
+        grid.attach(quitbutton, 0, 32, 4, 4)
         grid.attach_next_to(self.profiles_combo, profileslabel,
                             Gtk.PositionType.RIGHT, 8, 4)
         grid.attach_next_to(self.hostentry, hostlabel,
@@ -347,14 +346,14 @@ e.g. "1024x768" or "80%"''')
                             Gtk.PositionType.RIGHT, 8, 4)
         grid.attach_next_to(self.clioptionsentry, clioptionslabel,
                             Gtk.PositionType.RIGHT, 8, 4)
-        grid.attach_next_to(self.program_combo, programlabel,
-                            Gtk.PositionType.RIGHT, 8, 4)
-        grid.attach(self.homedirbutton, 0, 28, 4, 4)
+        grid.attach_next_to(self.xfreerdpbutton, programlabel,
+                            Gtk.PositionType.RIGHT, 4, 4)
+        grid.attach_next_to(self.rdesktopbutton, self.xfreerdpbutton,
+                            Gtk.PositionType.RIGHT, 4, 4)
         grid.attach_next_to(self.grabkeyboardbutton, self.homedirbutton,
                             Gtk.PositionType.RIGHT, 4, 4)
         grid.attach_next_to(self.fullscreenbutton, self.grabkeyboardbutton,
                             Gtk.PositionType.RIGHT, 4, 4)
-        grid.attach(quitbutton, 0, 32, 4, 4)
         grid.attach_next_to(self.connectbutton, quitbutton,
                             Gtk.PositionType.RIGHT, 8, 4)
         grid.attach_next_to(self.spinner, quitbutton,
@@ -451,8 +450,10 @@ e.g. "1024x768" or "80%"''')
         self.connectbutton.show()
         error_text = WorkerThread.error_text
         return_code = WorkerThread.return_code
-        # Display error popup in UI if 300 characaters or less
-        if return_code is not 0:
+        # return code 62 is a benign error code from rdesktop
+        # return code 62 is not used by xfreerdp
+        if return_code is not 0 and return_code is not 62:
+            # discard extra data from long error messages
             if len(error_text) > 300:
                 error_text = error_text[:300] + '...'
             self.on_warn(None, 'Connection Error', '%s: \n' % client +
@@ -468,14 +469,6 @@ e.g. "1024x768" or "80%"''')
                 self.load_settings()
         self.profilename = text
 
-    # Triggered when the combobox is clicked.  We set the selected RDP client.
-    def on_program_combo_changed(self, combo):
-        tree_iter = combo.get_active_iter()
-        if tree_iter is not None:
-            model = combo.get_model()
-            program = model[tree_iter][0]
-        options['program'] = program
-
     # Triggered when the checkboxes are toggled
     def on_button_toggled(self, button, name):
         if button.get_active():
@@ -485,6 +478,12 @@ e.g. "1024x768" or "80%"''')
             state = 'false'
             options[name] = state
 
+    # Triggered when the program radio buttons are toggled
+    def on_radio_button_toggled(self, button, name):
+        if button.get_active():
+            state = 'true'
+            options['program'] = name
+
     # Triggered when the file menu is used
     def add_file_menu_actions(self, action_group):
         action_filemenu = Gtk.Action(name="FileMenu", label="File",
@@ -591,10 +590,11 @@ e.g. "1024x768" or "80%"''')
     def on_about(self, widget):
         about = Gtk.AboutDialog()
         about.set_program_name("Rocket Depot")
-        about.set_version("0.18")
+        about.set_version("0.19")
         about.set_copyright("2014 David Roble")
         about.set_comments("rdesktop/xfreerdp Frontend")
         about.set_website("https://github.com/robled/rocket-depot")
+        about.set_logo(GdkPixbuf.Pixbuf.new_from_file("/usr/share/icons/hicolor/scalable/apps/rocket-depot.svg"))
         about.run()
         about.destroy()
 
@@ -604,7 +604,10 @@ e.g. "1024x768" or "80%"''')
         self.userentry.set_text(options['user'])
         self.geometryentry.set_text(options['geometry'])
         self.clioptionsentry.set_text(options['clioptions'])
-        self.program_combo.set_active(self.programs[options['program']])
+        if options['program'] == 'xfreerdp':
+            self.xfreerdpbutton.set_active(True)
+        if options['program'] == 'rdesktop':
+            self.rdesktopbutton.set_active(True)
         if options['homeshare'] == 'true':
             self.homedirbutton.set_active(True)
         else:
